<template>
    <div class="box">
        <div style="display: flex">
            <el-form
                ref="searchForm"
                :model="searchForm"
                label-width="80px"
                class="searchTop"
            >
                <CascaderCompany
                    :companyIds.sync="searchForm.companyIds"
                    :companyId.sync="searchForm.companyId"
                    :roadSegmentId.sync="searchForm.roadSegmentId"
                    :placeholder="'请选择公司名称'"
                />

                <!-- <el-select
                    v-model="searchForm.roadSegmentId"
                    placeholder="请选择路段"
                    clearable
                >
                    <el-option
                        v-for="item in roadData"
                        :key="item.key"
                        :label="item.value"
                        :value="item.key"
                    >
                    </el-option>
                </el-select> -->
                <dict-select
                    dictCode="qlfx"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.direction"
                    placeholder="请选择隧道方向"
                />
                <dict-select
                    dictCode="sdfl"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.type"
                    placeholder="请选择隧道分类"
                />
                <dict-select
                    dictCode="sddj"
                    :hasDefaultOption="true"
                    clearable
                    v-model="searchForm.grade"
                    placeholder="请选择隧道等级"
                />
                <el-date-picker
                    v-model="searchForm.finishDay"
                    type="date"
                    placeholder="请选择建成日期"
                    value-format="yyyy-MM-dd"
                >
                </el-date-picker>
                <el-button size="small" @click="findinfo()" type="primary"
                    >查询</el-button
                >
                <el-button size="small" @click="handleReset" type="plain">重置</el-button>
            </el-form>
        </div>
        <el-divider></el-divider>

        <ht-table
            @load="loadData"
            :data="data"
            :pageResult="pageResult"
            :selection="true"
            :show-export="false"
            :show-custom-column="false"
            ref="htTable"
            :default-sorter="[{direction: 'DESC', property: 'id_'}]"
        >
            <template>
                <ht-table-column
                    prop="number"
                    label="隧道编码"
                    :sortable="true"
                    width="110"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="name"
                    label="隧道名称"
                    :show-overflow-tooltip="true"
                    :sortable="true"
                />
                <!-- <ht-table-column
          prop="companyName"
          label="所属公司"
        /> -->

                <ht-table-column
                    prop="roadSegmentName"
                    label="所在路段"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="companyName"
                    label="所属公司"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="centPeg"
                    label="中心桩号"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="officeName"
                    label="管养单位"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column
                    prop="direction"
                    label="方向"
                    :show-overflow-tooltip="true"
                    :filters="getDictData('qlfx')"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('qlfx', row.direction) }}</el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="type"
                    label="隧道类型"
                    :show-overflow-tooltip="true"
                    :filters="getDictData('sdfl')"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('sdfl', row.type) }}</el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="grade"
                    label="隧道等级"
                    :show-overflow-tooltip="true"
                    :filters="getDictData('sddj')"
                >
                    <template v-slot="{row}">
                        <el-tag>{{ getDictName('sddj', row.grade) }}</el-tag>
                    </template>
                </ht-table-column>
                <ht-table-column
                    prop="length"
                    label="隧道长度"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="width"
                    :sortable="true"
                    label="隧道宽度"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="hight"
                    :sortable="true"
                    label="隧道高度"
                    :show-overflow-tooltip="true"
                />
                <ht-table-column
                    prop="finishDay"
                    label="建成年份"
                    :sortable="true"
                    :show-overflow-tooltip="true"
                >
                </ht-table-column>
                <ht-table-column label="操作" width="150">
                    <template v-slot="{row}">
                        <el-button type="pimary" @click="handleCommand(row)">
                            档案查看
                        </el-button>
                        <!-- <el-dropdown
              size="mini"
              split-button
              @command="handleCommand"
              @click="handleCommand({row, command: 'inspect'})"
            >
              <span> <i class="el-icon-edit"></i>检查记录</span>
              <el-dropdown-menu slot="dropdown">
                <el-dropdown-item
                  icon="el-icon-tickets"
                  :command="{row: row, command: 'disease'}"
                  >病害记录</el-dropdown-item
                >
                <el-dropdown-item
                  icon="el-icon-tickets"
                  :command="{row: row, command: 'curing'}"
                  >养护记录</el-dropdown-item
                >
              </el-dropdown-menu>
            </el-dropdown> -->
                    </template>
                </ht-table-column>
            </template>
        </ht-table>
    </div>
</template>

<script>
import basicData from '@/api/basicData.js'
import CascaderCompany from '@/components/selector/CascaderCompany.vue'
export default {
    components: {
        CascaderCompany,
    },
    data() {
        return {
            data: [],
            roadData: [],
            searchForm: {},
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
        }
    },
    created() {
        this.roadData = this.getroad()
    },
    methods: {
        getroad() {
            let arr = []
            basicData.getRoadManagement().then((res) => {
                res.rows.forEach((item) => {
                    arr.push({
                        value: item.name,
                        key: item.id,
                    })
                })
            })
            return arr
        },
        showDialog() {
            this.activeName = '1'
            this.dialogVisible = true
            let form = {
                type: 1,
                category: 1,
                direction: 1,
            }
            this.form = {...form}
        },
        uniqueFunc(arr, uniId) {
            const res = new Map()
            return arr.filter((item) => !res.has(item[uniId]) && res.set(item[uniId], 1))
        },
        handleReset() {
            this.searchForm = {
                ...this.searchForm,
                companyId: ['1419863231459102720'],
                companyIds: '',
                roadSegmentId: '',
                direction: '',
                grade: '',
                finishDay: '',
                type: '',
            }
            this.findinfo()
        },
        findinfo() {
            typeof this.$refs.filterTable !== 'undefined' &&
                this.$refs.filterTable.clearFilter()
            let query = []
            let params = {routeId: this.searchForm.routeId}

            let search = {
                company_id_: this.searchForm.companyIds,
                road_segment_id_: this.searchForm.roadSegmentId,
                finish_day_: this.searchForm.finishDay,
                type: this.searchForm.type,
                grade: this.searchForm.grade,
                direction: this.searchForm.direction,
            }
            for (let i in search) {
                if (search[i]) {
                    if (i == 'company_id_') {
                        query.push({
                            group: 'companyIds',
                            operation: 'IN',
                            parentGroup: '',
                            property: 'COMPANY_ID_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else if (i == 'road_segment_id_') {
                        query.push({
                            group: 'main',
                            operation: 'EQUAL',
                            parentGroup: '',
                            property: 'road_segment_id_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else {
                        query.push({
                            group: 'advance',
                            operation: 'LIKE',
                            property: i,
                            relation: 'AND',
                            value: search[i],
                        })
                    }
                }
            }
            query = this.uniqueFunc(query, 'property')
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: query,
                params: params,
            }
            this.topQuery = query
            basicData.getTunnelManagement(data).then((res) => {
                console.log(res, '11')

                this.data = res.rows
                this.pageResult = {
                    page: res.page,
                    pageSize: res.pageSize,
                    total: res.total,
                }
            })
        },
        loadData(param, cb) {
            // let r = JSON.stringify(param.pageBean)
            // let l = JSON.stringify(this.pageResult)
            // console.log(r, l)
            // if (r == l) {
            //   console.log('一样')
            //   param
            // } else {
            //   console.log('不一样')
            //   let query = []
            //   let params = {routeId: this.searchForm.routeId}
            //   let search = {
            //     company_id_: this.searchForm.companyId,
            //     road_segment_name_: this.searchForm.roadSegmentName,
            //     finish_day_: this.searchForm.finishDay,
            //     type: this.searchForm.type
            //   }
            //   for (let i in search) {
            //     if (search[i]) {
            //       query.push({
            //         group: 'advance',
            //         operation: 'LIKE',
            //         property: i,
            //         relation: 'AND',
            //         value: search[i]
            //       })
            //     }
            //   }
            //   param.querys = query
            //   param.params = params
            // }
            if (typeof this.topQuery !== 'undefined' && this.topQuery.length !== 0) {
                param.querys = typeof param.querys !== 'undefined' ? param.querys : []
                this.topQuery.forEach((item) => {
                    param.querys.push(item)
                })
                param.querys = this.uniqueFunc(param.querys, 'property')
            }
            this.exportQuery = param
            basicData
                .getTunnelManagement(param)
                .then(
                    (resp) => {
                        console.log(resp)
                        this.data = resp.rows
                        this.pageResult = {
                            page: resp.page,
                            pageSize: resp.pageSize,
                            total: resp.total,
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
        handleCommand(params) {
            let params_ = {
                row: params,
                sign: 'tunnel',
            }
            this.$router.push({
                name: 'inspectTunnel',
                params: params_,
            })
            //   if (params.command == 'inspect') {
            //     this.$router.push({
            //       name: 'inspectTunnel',
            //       params
            //     })
            //   } else if (params.command == 'disease') {
            //     this.$router.push({
            //       name: 'tunnelDisease',
            //       params
            //     })
            //   } else if (params.command == 'curing') {
            //     params.sign = 'tunnel'
            //     this.$router.push({
            //       name: 'workOrderInfo',
            //       params
            //     })
            //   }
        },
    },
}
</script>

<style lang="scss" scoped>
.box {
    // padding: 10px;
}
// /deep/ .el-main {
//   .el-table {
//     height: 745px !important;
//   }
// }
/deep/.el-dialog__header {
    border-bottom: 1px solid #eee;
}
/deep/.el-dialog::-webkit-scrollbar {
    display: none;
}
/deep/ .el-date-editor.el-input,
.el-date-editor.el-input__inner {
    width: 100%;
}
/deep/.el-form-item__label {
    width: 100px;
}
.is-required:before {
    margin-right: 0;
}
/deep/.el-form-item__content {
    flex: 1;
    margin-left: 0 !important;
}
/deep/ .el-form-item__content .inputs {
    width: 100%;
}
/deep/.el-divider--horizontal {
    height: 10px;
    margin: 0 !important;
    position: absolute;
    left: 0;
}
/deep/.ht-table-panel {
    // padding-top: 20px;
    // height: calc(100% - 7%);
    overflow: hidden;
    // background: #fff;
    // display: flex;
    // flex-direction: column;
    // justify-content: space-between;
}
/deep/.ht-quick__search {
    margin-bottom: 10px;
}
/deep/.ht-table {
    // height: calc(100% - 4vw) !important;
    // max-height: calc(100% - 4vw) !important;
}
/deep/.pagination-panel {
    // padding: 10px 0 0 0;
}
.searchTop > div {
    max-width: 200px;
}
</style>
